summaryrefslogtreecommitdiffstats
path: root/chrome_frame/chrome_frame_activex.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome_frame/chrome_frame_activex.cc')
-rw-r--r--chrome_frame/chrome_frame_activex.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome_frame/chrome_frame_activex.cc b/chrome_frame/chrome_frame_activex.cc
index 5aa9294..f137aad 100644
--- a/chrome_frame/chrome_frame_activex.cc
+++ b/chrome_frame/chrome_frame_activex.cc
@@ -445,10 +445,10 @@ HRESULT ChromeFrameActivex::IOleObject_SetClientSite(
std::string automated_functions(
WideToASCII(static_cast<BSTR>(automated_functions_arg)));
functions_enabled_.clear();
// SplitString writes one empty entry for blank strings, so we need this
// to allow specifying zero automation of API functions.
if (!automated_functions.empty())
- SplitString(automated_functions, ',', &functions_enabled_);
+ base::SplitString(automated_functions, ',', &functions_enabled_);
}
ScopedBstr profile_name_arg;
@@ -445,10 +445,10 @@ HRESULT ChromeFrameActivex::IOleObject_SetClientSite(
WideToASCII(static_cast<BSTR>(automated_functions_arg)));
functions_enabled_.clear();
- // SplitString writes one empty entry for blank strings, so we need this
- // to allow specifying zero automation of API functions.
+ // base::SplitString writes one empty entry for blank strings, so we
+ // need this to allow specifying zero automation of API functions.
if (!automated_functions.empty())